
======================
Package CSAMT
======================


**Module AVG**
=================
.. automodule:: pycsamt.ff.core.avg
	:members:
	
**Module CS**
==================
.. automodule:: pycsamt.ff.core.cs
	:members:
	
**Module EDI**
===================
.. automodule:: pycsamt.ff.core.edi
    :members:


**Module J**
===================
.. automodule:: pycsamt.ff.core.j
    :members:


**Module z**
====================
.. automodule:: pycsamt.ff.core.z
    :members:








